@@ -80,6 +80,7 @@ def update_domain(new_domain):
             f.write(domain)
 
 domain = get_domain()
+jupyterDrive = ""
 jupyterHome = ""
 
 
@@ -293,8 +294,8 @@ class PreviewNotebookHandler(IPythonHandler):
     async def post(self):
         try:
             data = json.loads(self.request.body)
-            notebook = data['notebook']
-            response = await IOLoop.current().run_in_executor(None, preview_notebook, notebook)
+            nbConfig = data['nbConfig']
+            response = await IOLoop.current().run_in_executor(None, preview_notebook, nbConfig)
             self.set_status(401 if response.geturl().endswith('/login') else response.getcode())
             self.write(response.read())
             if response.getcode() >= 300: jupyter_log.info(optumi_start(self) + str(response))
@@ -318,7 +319,8 @@ class SetupNotebookHandler(IPythonHandler):
             name = data['name']
             timestamp = data['timestamp']
             notebook = data['notebook']
-            response = await IOLoop.current().run_in_executor(None, setup_notebook, name, timestamp, notebook)
+            nbConfig = data['nbConfig']
+            response = await IOLoop.current().run_in_executor(None, setup_notebook, name, timestamp, notebook, nbConfig)
             self.set_status(401 if response.geturl().endswith('/login') else response.getcode())
             self.write(response.read())
             if response.getcode() >= 300: jupyter_log.info(optumi_start(self) + str(response))
@@ -500,6 +502,98 @@ class GetMachinesHandler(IPythonHandler):
             jupyter_log.error(optumi_start(self) + str(e))
             if DEBUG: raise e
 
+class GetNotebookConfigHandler(IPythonHandler):
+    @authenticated
+    async def post(self):
+        try:
+            data = json.loads(self.request.body)
+            nbKey = data['nbKey']
+            response = await IOLoop.current().run_in_executor(None, get_notebook_config, nbKey)
+            self.set_status(401 if response.geturl().endswith('/login') else response.getcode())
+            self.write(response.read())
+            if response.getcode() >= 300: jupyter_log.info(optumi_start(self) + str(response))
+        except (ConnectionError, URLError) as e:
+            # If we can't connect to the REST interface, we want the extension to treat it as the user being loggeed out
+            self.set_status(401)
+            self.write(json.dumps({'message': str(e)}))
+            jupyter_log.warning(optumi_start(self) + str(e))
+            if DEBUG: raise e
+        except Exception as e:
+            self.set_status(500)
+            self.write(json.dumps({'message': 'Encountered error while getting notebook config'}))
+            jupyter_log.error(optumi_start(self) + str(e))
+            if DEBUG: raise e
+
+class SetNotebookConfigHandler(IPythonHandler):
+    @authenticated
+    async def post(self):
+        try:
+            data = json.loads(self.request.body)
+            nbKey = data['nbKey']
+            nbConfig = data['nbConfig']
+            response = await IOLoop.current().run_in_executor(None, set_notebook_config, nbKey, nbConfig)
+            self.set_status(401 if response.geturl().endswith('/login') else response.getcode())
+            self.write(response.read())
+            if response.getcode() >= 300: jupyter_log.info(optumi_start(self) + str(response))
+        except (ConnectionError, URLError) as e:
+            # If we can't connect to the REST interface, we want the extension to treat it as the user being loggeed out
+            self.set_status(401)
+            self.write(json.dumps({'message': str(e)}))
+            jupyter_log.warning(optumi_start(self) + str(e))
+            if DEBUG: raise e
+        except Exception as e:
+            self.set_status(500)
+            self.write(json.dumps({'message': 'Encountered error while setting notebook config'}))
+            jupyter_log.error(optumi_start(self) + str(e))
+            if DEBUG: raise e
+
+
+class PullWorkloadConfigHandler(IPythonHandler):
+    @authenticated
+    async def post(self):
+        try:
+            data = json.loads(self.request.body)
+            workload = data['workload']
+            response = await IOLoop.current().run_in_executor(None, pull_workload_config, workload)
+            self.set_status(401 if response.geturl().endswith('/login') else response.getcode())
+            self.write(response.read())
+            if response.getcode() >= 300: jupyter_log.info(optumi_start(self) + str(response))
+        except (ConnectionError, URLError) as e:
+            # If we can't connect to the REST interface, we want the extension to treat it as the user being loggeed out
+            self.set_status(401)
+            self.write(json.dumps({'message': str(e)}))
+            jupyter_log.warning(optumi_start(self) + str(e))
+            if DEBUG: raise e
+        except Exception as e:
+            self.set_status(500)
+            self.write(json.dumps({'message': 'Encountered error while pulling workload config'}))
+            jupyter_log.error(optumi_start(self) + str(e))
+            if DEBUG: raise e
+
+class PushWorkloadConfigHandler(IPythonHandler):
+    @authenticated
+    async def post(self):
+        try:
+            data = json.loads(self.request.body)
+            workload = data['workload']
+            nbConfig = data['nbConfig']
+            response = await IOLoop.current().run_in_executor(None, push_workload_config, workload, nbConfig)
+            self.set_status(401 if response.geturl().endswith('/login') else response.getcode())
+            self.write(response.read())
+            if response.getcode() >= 300: jupyter_log.info(optumi_start(self) + str(response))
+        except (ConnectionError, URLError) as e:
+            # If we can't connect to the REST interface, we want the extension to treat it as the user being loggeed out
+            self.set_status(401)
+            self.write(json.dumps({'message': str(e)}))
+            jupyter_log.warning(optumi_start(self) + str(e))
+            if DEBUG: raise e
+        except Exception as e:
+            self.set_status(500)
+            self.write(json.dumps({'message': 'Encountered error while pushing workload config'}))
+            jupyter_log.error(optumi_start(self) + str(e))
+            if DEBUG: raise e
+
+
 class GetDataConnectorsHandler(IPythonHandler):
     @authenticated
     async def get(self):
@@ -896,26 +990,17 @@ class DisconnectSessionHandler(IPythonHandler):
             if DEBUG: raise e
 
 # Get a windows path in a format we can use on linux
-def fix_path_for_linux(path):
-    letters = ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z']
-
-    fixed = path
-
-    # Remove letter and : at the beginning
-    for letter in letters:
-        if fixed.startswith(letter + ':'):
-            fixed = fixed.replace(letter + ':', '', 1)
-            break
-        if fixed.startswith(letter.upper() + ':'):
-            fixed = fixed.replace(letter.upper() + ':', '', 1)
-            break
+def extract_drive_and_fix_path(path):
+    # Extract the drive
+    drive, path = os.path.splitdrive(path)
 
     # Switch slashes to correct direction
-    fixed = fixed.replace('\\', '/')
+    path = path.replace('\\', '/')
 
-    return fixed
+    return drive, path
 
 def setup_handlers(server_app):
+    global jupyterDrive
     global jupyterHome
     global jupyter_log
 
@@ -923,7 +1008,7 @@ def setup_handlers(server_app):
 
     web_app = server_app.web_app
     base_url = web_app.settings['base_url']
-    jupyterHome = fix_path_for_linux(os.path.expanduser(web_app.settings['server_root_dir']))
+    jupyterDrive, jupyterHome = extract_drive_and_fix_path(os.path.expanduser(web_app.settings['server_root_dir']))
     host_pattern = '.*$'
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/version'), VersionHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/login'), LoginHandler)])
@@ -939,11 +1024,15 @@ def setup_handlers(server_app):
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/stop-notebook'), StopNotebookHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/teardown-notebook'), TeardownNotebookHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-machines'), GetMachinesHandler)])
+    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-notebook-config'), GetNotebookConfigHandler)])
+    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/set-notebook-config'), SetNotebookConfigHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-data-connectors'), GetDataConnectorsHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/add-data-connector'), AddDataConnectorHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/remove-data-connector'), RemoveDataConnectorHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/push-workload-status-update'), PushWorkloadStatusUpdateHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/pull-workload-status-updates'), PullWorkloadStatusUpdatesHandler)])
+    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/pull-workload-config'), PullWorkloadConfigHandler)])
+    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/push-workload-config'), PushWorkloadConfigHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/pull-module-status-updates'), PullModuleStatusUpdateHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/push-module-input'), PushModuleInputHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/save-notebook-output-file'), SaveNotebookOutputFileHandler)])
@@ -1067,11 +1156,12 @@ def set_user_information(param, value):
     except HTTPError as e:
         return e
 
-def preview_notebook(notebook):
+def preview_notebook(nbConfig):
     URL = get_path() + '/exp/jupyterlab/preview-notebook'
     try:
         form = MultiPartForm()
-        form.add_file('notebook', notebook['path'], fileHandle=io.BytesIO(notebook['content'].encode('utf-8')))
+        ## Send this string as a file since it can have arbitrary length and cause issues for the REST Interface if sent as a string
+        form.add_file('nbConfig', 'nbConfig', fileHandle=io.BytesIO(nbConfig.encode('utf-8')))
 
         # Build the request, including the byte-string
         # for the data to be posted.
@@ -1095,13 +1185,15 @@ def preview_notebook(notebook):
     except HTTPError as e:
         return e
 
-def setup_notebook(name, timestamp, notebook):
+def setup_notebook(name, timestamp, notebook, nbConfig):
     URL = get_path() + '/exp/jupyterlab/setup-notebook'
     try:
         form = MultiPartForm()
         form.add_field('name', name)
         form.add_field('timestamp', timestamp)
         form.add_file('notebook', notebook['path'], fileHandle=io.BytesIO(notebook['content'].encode('utf-8')))
+        ## Send this string as a file since it can have arbitrary length and cause issues for the REST Interface if sent as a string
+        form.add_file('nbConfig', 'nbConfig', fileHandle=io.BytesIO(nbConfig.encode('utf-8')))
         data = bytes(form)
 
         req = request.Request(URL, data=data)
@@ -1120,8 +1212,9 @@ def launch_notebook(requirementsFile, dataFiles, compress, uuid, timestamp):
         ## Send this list as a file since it can have arbitrary length and cause issues for the REST Interface if sent as an array
         form.add_file('dataFileNames', 'dataFileNames', fileHandle=io.BytesIO(','.join(dataFiles).encode('utf-8')))
         form.add_field('timestamp', timestamp)
+        form.add_field('jupyterDrive', jupyterDrive)
         form.add_field('jupyterHome', jupyterHome)
-        form.add_field('userHome', fix_path_for_linux(os.path.expanduser('~')))
+        form.add_field('userHome', extract_drive_and_fix_path(os.path.expanduser('~'))[1])
 
         try:
             lock.acquire()
@@ -1305,6 +1398,64 @@ def get_machines():
     except HTTPError as e:
         return e
 
+def pull_workload_config(workload):
+    URL = get_path() + '/exp/jupyterlab/pull-workload-config'
+    try:
+        form = MultiPartForm()
+        form.add_field('workload', workload)
+        data = bytes(form)
+
+        req = request.Request(URL, data=data)
+        req.add_header('Content-type', form.get_content_type())
+        req.add_header('Content-length', len(data))
+        return request.urlopen(req)
+    except HTTPError as e:
+        return e
+
+def push_workload_config(workload, nbConfig):
+    URL = get_path() + '/exp/jupyterlab/push-workload-config'
+    try:
+        form = MultiPartForm()
+        form.add_field('workload', workload)
+        form.add_field('nbConfig', nbConfig)
+        data = bytes(form)
+
+        req = request.Request(URL, data=data)
+        req.add_header('Content-type', form.get_content_type())
+        req.add_header('Content-length', len(data))
+        return request.urlopen(req)
+    except HTTPError as e:
+        return e
+
+def get_notebook_config(nbKey):
+    URL = get_path() + '/exp/jupyterlab/get-notebook-config'
+    try:
+        form = MultiPartForm()
+        form.add_field('nbKey', nbKey)
+        data = bytes(form)
+
+        req = request.Request(URL, data=data)
+        req.add_header('Content-type', form.get_content_type())
+        req.add_header('Content-length', len(data))
+        return request.urlopen(req)
+    except HTTPError as e:
+        return e
+
+def set_notebook_config(nbKey, nbConfig):
+    URL = get_path() + '/exp/jupyterlab/set-notebook-config'
+    try:
+        form = MultiPartForm()
+        form.add_field('nbKey', nbKey)
+        form.add_field('nbConfig', nbConfig)
+        data = bytes(form)
+
+        req = request.Request(URL, data=data)
+        req.add_header('Content-type', form.get_content_type())
+        req.add_header('Content-length', len(data))
+        return request.urlopen(req)
+    except HTTPError as e:
+        return e
+
 def get_data_connectors():
     URL = get_path() + '/exp/jupyterlab/get-data-connectors'
     try:
