@@ -134,10 +134,8 @@ export class Global {
     private static _user: User = null // If we are logged in we will have a user, otherwise it will be null
     public static get user(): User { return Global._user }
     public static set user(user: User) {
-        if (this._user != null) {
-            this._user.appTracker.stopPolling();
-        }
         if (user == null) {
+            this._user.appTracker.stopPolling();
             if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
             Global._onNullUser.emit(null)
         }
@@ -151,9 +149,13 @@ export class Global {
         Global.lastCreditsBalance = 0;
         Global.lastBudgetCost = 0;
         Global.lastDataConnectors = [];
-        // Signal
-        if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
-        Global._onUserChange.emit(user)
+
+        // Refresh the metadata before continuing with the login
+        this._metadata.refreshMetadata().then(() => {
+            // Wait to signal the change until the metadata has been set properly
+            if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
+            Global._onUserChange.emit(user)
+        });
     }
 
     private static _onUserChange: Signal<Global, User> = new Signal<Global, User>(Global.emitter)
