@@ -16,7 +16,7 @@ import { AccountConnectorsSubMenu, AccountGeneralSubMenu, AccountLimitsSubMenu,
 import { ShadowedDivider } from '../core';
 import { User } from '../models/User';
 import WarningPopup from '../core/WarningPopup';
-import { App } from '../models/App';
+import { App } from '../models/application/App';
 
 const StyledDialog = withStyles({
     paper: {
@@ -47,6 +47,8 @@ interface IState {
     open: boolean,
     selectedPanel: number,
     showLogoutWithSessionPopup: boolean,
+    validPhoneNumber: boolean,
+    showCloseWithInvalidNumberPopup: boolean,
 }
 
 // TODO:Beck The popup needs to be abstracted out, there is too much going on to reproduce it in more than one file
@@ -59,6 +61,8 @@ export class UserDialog extends React.Component<IProps, IState> {
             open: false,
             selectedPanel: Page.GENERAL,
             showLogoutWithSessionPopup: false,
+            validPhoneNumber: true,
+            showCloseWithInvalidNumberPopup: false,
 		};
     }
 
@@ -76,7 +80,7 @@ export class UserDialog extends React.Component<IProps, IState> {
 	}
 
 	private handleClose = () => {
-        this.safeSetState({ open: false });
+        this.safeSetState({ open: false, validPhoneNumber: true });
         if (this.props.onClose) this.props.onClose();
         if (this.resolveOpenToPromise) {
 			this.resolveOpenToPromise()
@@ -123,7 +127,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                         borderRadius: '12px',
                         backgroundColor: '#10A0F9',
                         color: 'white',
-                        fontSize: '18px',
+                        fontSize: '14px',
                         fontWeight: 'bold',
                         lineHeight: '24px',
                         textAlign: 'center'
@@ -133,7 +137,13 @@ export class UserDialog extends React.Component<IProps, IState> {
                 </IconButton>
                 <StyledDialog
 					open={this.state.open}
-					onClose={this.handleClose}
+					onClose={() => {
+                        if (!this.state.validPhoneNumber) {
+                            this.safeSetState({ showCloseWithInvalidNumberPopup: true });
+                        } else {
+                            this.handleClose();
+                        }
+                    }}
                     scroll='paper'
 				>
 					<MuiDialogTitle
@@ -198,24 +208,51 @@ export class UserDialog extends React.Component<IProps, IState> {
                                 Logout
                             </Button>
                         </div>
-                        <IconButton
-                            onClick={this.handleClose}
-                            style={{
-                                margin: '6px',
-                                display: 'inline-block',
-                                width: '36px',
-                                height: '36px',
-                                padding: '3px',
-                            }}
-                        >
-                            <CloseIcon
-                                style={{
-                                    width: '30px',
-                                    height: '30px',
-                                    padding: '3px',
+                        <div>
+                            <WarningPopup
+                                open={this.state.showCloseWithInvalidNumberPopup}
+                                headerText="Heads Up!"
+                                bodyText={`The phone number you entered is invalid. If you continue we'll revert back to your previous number.`}
+                                cancel={{
+                                    text: `Edit number`,
+                                    onCancel: (prevent: boolean) => {
+                                        this.safeSetState({ showCloseWithInvalidNumberPopup: false })
+                                    },
+                                }}
+                                continue={{
+                                    text: `Continue`,
+                                    onContinue: (prevent: boolean) => {
+                                        this.safeSetState({ showCloseWithInvalidNumberPopup: false })
+                                        this.handleClose()
+                                    },
+                                    color: `primary`,
                                 }}
                             />
-                        </IconButton>
+                            <IconButton
+                                onClick={() => {
+                                    if (!this.state.validPhoneNumber) {
+                                        this.safeSetState({ showCloseWithInvalidNumberPopup: true });
+                                    } else {
+                                        this.handleClose();
+                                    }
+                                }}
+                                style={{
+                                    margin: '6px',
+                                    display: 'inline-block',
+                                    width: '36px',
+                                    height: '36px',
+                                    padding: '3px',
+                                }}
+                            >
+                                <CloseIcon
+                                    style={{
+                                        width: '30px',
+                                        height: '30px',
+                                        padding: '3px',
+                                    }}
+                                />
+                            </IconButton>
+                        </div>
 					</MuiDialogTitle>
                     <ShadowedDivider />
                     <div style={{display: 'flex', height: 'calc(100% - 60px - 2px'}}>
@@ -239,6 +276,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                                                 minHeight: '36px',
                                             }}
                                             value={Page.GENERAL}
+                                            
                                         />
                                         <Tab
                                             label='LIMITS'
@@ -284,7 +322,10 @@ export class UserDialog extends React.Component<IProps, IState> {
                                 fontSize: 'var(--jp-ui-font-size1)',
                                 fontFamily: 'var(--jp-ui-font-family)',
                             }}>
-                                <div style={{display: 'flex', flexFlow: 'column', overflow: 'hidden'}}>
+                                <div style={{
+                                    // Height needs to be 100% otherwise it will cause problems with the phone number country selection
+                                    display: 'flex', flexFlow: 'column', overflow: 'hidden', height: '100%'
+                                }}>
                                     {this.state.selectedPanel == Page.GENERAL ? (
                                         <>
                                             <div style={{display: 'flex', padding: '6px 6px 0px 6px', maxWidth: '450px'}}>
@@ -313,7 +354,12 @@ export class UserDialog extends React.Component<IProps, IState> {
                                                     </div>
                                                 </div>
                                             </div>
-                                            <AccountGeneralSubMenu style={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}} />
+                                            <AccountGeneralSubMenu
+                                                style={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}}
+                                                phoneValidOnBlur={(valid: boolean) => {
+                                                    this.setState({ validPhoneNumber: valid });
+                                                }}
+                                            />
                                         </>
                                     ) : this.state.selectedPanel == Page.LIMITS ? (
                                         <AccountLimitsSubMenu style={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}} />
