@@ -50,7 +50,7 @@ export class GoogleCloudStorageConnectorPopup extends React.Component<IProps, IS
                 iconClass='jp-cloud-logo'
                 description='Access a Cloud Storage bucket'
                 header='Connect to a Google Cloud Storage bucket using a Service Account.'
-                downloadPath='~/gcp/'
+                downloadPath=''
                 onClose={this.handleClose}
                 getInfo={() => this.state}
                 getContents={(waiting: boolean) => (
@@ -69,6 +69,7 @@ export class GoogleCloudStorageConnectorPopup extends React.Component<IProps, IS
                             saveValue={(value: string) => this.safeSetState({ serviceAccountKey: value })}
                             label='Service Account Key'
                             helperText='The contents of the credentials file generated for your Google Service Account.'
+                            helperLink={{link: 'https://cloud.google.com/iam/docs/service-accounts', text: 'learn more'}}
                             labelWidth={BaseConnectorPopup.LABEL_WIDTH}
                             disabled={waiting}
                             multiline
