@@ -52,7 +52,7 @@ export class KaggleConnectorPopup extends React.Component<IProps, IState> {
                 iconClass='jp-kaggle-logo'
                 description='Access a Kaggle dataset'
                 header='Connect to a Kaggle dataset using an API Token.'
-                downloadPath='~/kaggle/'
+                downloadPath=''
                 onClose={this.handleClose}
                 getInfo={() => this.state}
                 getContents={(waiting: boolean) => (
