@@ -8,7 +8,7 @@
 import * as React from 'react';
 import { Global } from '../../Global';
 
-import { App } from '../../models/App';
+import { App } from '../../models/application/App';
 import { OutputFileEntry } from './OutputFileEntry';
 
 import {
@@ -104,7 +104,7 @@ export class OutputFileList extends React.Component<IProps, IState> {
                             name={'Download stdout as file'}
 							lastModified=""
 							size={0}
-                            files={[this.props.app.name.replace('.ipynb', '.stdout')]}
+                            files={[this.props.app.path.replace('.ipynb', '.stdout')]}
                             workloadUUID={this.props.app.uuid}
                             moduleUUID={this.props.app.modules[0].uuid}
                             disabled={false}
@@ -115,7 +115,7 @@ export class OutputFileList extends React.Component<IProps, IState> {
                             name={'Download stderr as file'}
 							lastModified=""
 							size={0}
-                            files={[this.props.app.name.replace('.ipynb', '.stderr')]}
+                            files={[this.props.app.path.replace('.ipynb', '.stderr')]}
                             workloadUUID={this.props.app.uuid}
                             moduleUUID={this.props.app.modules[0].uuid}
                             disabled={false}
@@ -125,7 +125,7 @@ export class OutputFileList extends React.Component<IProps, IState> {
 							name={'Download all files'}
 							size={sorted.length == 0 ? 0 : sorted.reduce((a, b) => { return { size: a.size + b.size } }, {size: 0}).size}
 							lastModified=""
-							files={sorted.map((value: any) => value.file).concat(this.props.app.interactive ? [this.props.app.name.replace('.ipynb', '.stderr'), this.props.app.name.replace('.ipynb', '.stdout')] : [])}
+							files={sorted.map((value: any) => value.file).concat(this.props.app.interactive ? [this.props.app.path.replace('.ipynb', '.stderr'), this.props.app.path.replace('.ipynb', '.stdout')] : [])}
 							workloadUUID={this.props.app.uuid}
 							moduleUUID={this.props.app.modules[0].uuid}
 							disabled={!this.props.app.interactive && sorted.length == 0}
