@@ -72,7 +72,7 @@ export default class FileBrowser extends React.Component<IProps, IState> {
     private handleOpen = (file: FileMetadata) => {
         if (file.type === 'directory') {
             this.request('/contents/' + file.path).then(json => {
-                const newPath = this.state.path
+                const newPath = [...this.state.path]
                 const depth = file.path.replace(/[^/]/g, '').length
                 while (newPath.length > depth) newPath.pop();
                 if (file !== this.state.root) newPath.push(file)
