@@ -11,7 +11,7 @@ import { Global } from '../../../Global';
 import { Slider } from '../../../core';
 import { User } from '../../../models/User';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
-import { ComputeMetadata } from '../../../models/ComputeMetadata';
+import { ComputeConfig } from '../../../models/ComputeConfig';
 
 interface IProps {
     style?: React.CSSProperties,
@@ -24,14 +24,14 @@ export class ComputeSimplified extends React.Component<IProps, IState> {
     private getCoresValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const compute: ComputeMetadata = optumi.metadata.compute;
+        const compute: ComputeConfig = optumi.config.compute;
         return compute.cores[0];
     }
 
     private async saveCoresValue(cores: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const compute: ComputeMetadata = optumi.metadata.compute;
+        const compute: ComputeConfig = optumi.config.compute;
         compute.cores = [cores, -1, -1];
         tracker.setMetadata(optumi);
     }
