@@ -10,7 +10,7 @@ import { Global } from '../../../Global';
 
 import { GraphicsCard } from '../../../models/GraphicsCard';
 import { MenuItem, Select, withStyles } from '@material-ui/core';
-import { GraphicsMetadata } from '../../../models/GraphicsMetadata';
+import { GraphicsConfig } from '../../../models/GraphicsConfig';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 
 interface IProps {
@@ -61,14 +61,14 @@ export class GraphicsEquipment extends React.Component<IProps, IState> {
     private getCardValue(): string {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         return graphics.boardType;
 	}
 
 	private async saveCardValue(value: string) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         graphics.boardType = value;
         tracker.setMetadata(optumi);
     }
@@ -76,14 +76,14 @@ export class GraphicsEquipment extends React.Component<IProps, IState> {
     private getNumCardValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         return graphics.boardCount[0];
 	}
 
 	private async saveNumCardValue(value: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         graphics.boardCount = [value, -1, -1];
         tracker.setMetadata(optumi);
 	}
