@@ -9,7 +9,7 @@ import * as React from 'react';
 import { Global } from '../../../Global';
 
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
-import { StorageMetadata } from '../../../models/StorageMetadata';
+import { StorageConfig } from '../../../models/StorageConfig';
 import { Switch } from '../../../core';
 
 interface IProps {
@@ -23,7 +23,7 @@ export class StorageBasic extends React.Component<IProps, IState> {
     private getValue(): boolean {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const storage: StorageMetadata = optumi.metadata.storage;
+		const storage: StorageConfig = optumi.config.storage;
         return storage.required;
         return false
 	}
@@ -31,7 +31,7 @@ export class StorageBasic extends React.Component<IProps, IState> {
 	private async saveValue(checked: boolean) {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-        const storage: StorageMetadata = optumi.metadata.storage;
+        const storage: StorageConfig = optumi.config.storage;
         storage.required = checked;
         tracker.setMetadata(optumi);
 	}
