@@ -23,9 +23,11 @@ import { GoogleCloudStorageConnectorPopup } from '../deploy/GoogleCloudStorageCo
 import { GoogleDriveConnectorPopup } from '../deploy/GoogleDriveConnectorPopup';
 import { KaggleConnectorPopup } from '../deploy/KaggleConnectorPopup';
 import { WasabiConnectorPopup } from '../deploy/WasabiConnectorPopup';
+import { PhoneTextBox } from '../../core/PhoneTextBox';
 
 // Properties from parent
 interface IProps {
+    phoneValidOnBlur?: (valid: boolean) => void
 	style?: CSSProperties
 }
 
@@ -36,23 +38,25 @@ const emUpSub = 'Upgrade subscription to unlock'
 
 const LABEL_WIDTH = '80px'
 
-interface IAccountGeneralSubMenuState {}
+interface IAccountGeneralSubMenuState {
+    switchKey: number
+}
 
 export class AccountGeneralSubMenu extends React.Component<IProps, IAccountGeneralSubMenuState> {
 
     constructor(props: IProps) {
         super(props);
-        this.state = {}
+        this.state = {
+            // We need to increment this when the user changes his number so the switch will be enabled/disabled properly
+            switchKey: 0
+        }
     }
 
     private getPasswordValue(): string { return '******' }
     private savePasswordValue(password: string) {
         Global.user.changePassword("", "", password);
     }
-
-    private getCompressFilesEnabledValue(): boolean { return Global.user.compressFilesEnabled }
-    private saveCompressFilesEnabledValue(compressFilesEnabled: boolean) { Global.user.compressFilesEnabled = compressFilesEnabled }
-
+    
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
@@ -73,22 +77,32 @@ export class AccountGeneralSubMenu extends React.Component<IProps, IAccountGener
                         />
                         <ChangePasswordPopup style={{margin: '8px 0px', height: '20px', fontSize: '12px', lineHeight: '12px'}}/>
                     </div>
-                    {/* <ExtraInfo
-                        reminder={`Compress files before uploading`}
-                    > */}
+                    <PhoneTextBox
+                        getValue={() => Global.user.phoneNumber}
+                        saveValue={(phoneNumber: string) => {
+                            if (phoneNumber == '') Global.user.notificationsEnabled = false;
+                            Global.user.phoneNumber = phoneNumber;
+                            // We need to update so the switch below will be updated properly
+                            this.setState({ switchKey: this.state.switchKey+1 });
+                        }}
+                        validOnBlur={this.props.phoneValidOnBlur}
+                        label='Phone'
+                        labelWidth={LABEL_WIDTH}
+                    />
                     <Switch
-                        getValue={this.getCompressFilesEnabledValue}
-                        saveValue={this.saveCompressFilesEnabledValue}
+                        key={this.state.switchKey}
+                        getValue={() => Global.user.notificationsEnabled }
+                        saveValue={(notificationsEnabled: boolean) => { Global.user.notificationsEnabled = notificationsEnabled }}
+                        label='Enable SMS notifications to the listed phone number'
+                        labelWidth={LABEL_WIDTH}
+                        disabled={Global.user.phoneNumber == ''}
+                    />
+                    <Switch
+                        getValue={() => Global.user.compressFilesEnabled}
+                        saveValue={(compressFilesEnabled: boolean) => { Global.user.compressFilesEnabled = compressFilesEnabled }}
                         label='Compress my files before uploading'
                         labelWidth={LABEL_WIDTH}
                     />
-                    {/* </ExtraInfo> */}
-                    {/* <ResourceSwitch
-                        tooltip='Start uploading files&#10;before launching'
-                        getValue={() => false}
-                        saveValue={() => {}}
-                        label='Preupload'
-                    /> */}
                 </div>
             </>
         )
@@ -126,9 +140,6 @@ export class AccountLimitsSubMenu extends React.Component<IProps, IAccountLimits
     private getUserBudgetValue(): number { return Global.user.userBudget }
     private saveUserBudgetValue(userBudget: number) { Global.user.userBudget = userBudget }
 
-    private getUserRecommendationsValue(): number { return Global.user.userRecommendations }
-    private saveUserRecommendationsValue(userRecommendations: number) { Global.user.userRecommendations = userRecommendations }
-
     private getMaxJobsValue(): number { return Global.user.maxJobs }
     private saveMaxJobsValue(value: number) { Global.user.maxJobs = value }
 
@@ -157,18 +168,6 @@ export class AccountLimitsSubMenu extends React.Component<IProps, IAccountLimits
                         maxValue={Global.user.maxBudget}
                         // disabledMessage={Global.user.userExpertise < 2 ? emUpSub : ''}
                     />) : (<></>)}
-                    <TextBox<number>
-                        getValue={this.getUserRecommendationsValue}
-                        saveValue={this.saveUserRecommendationsValue}
-                        label='Alternatives'
-                        labelWidth={LABEL_WIDTH}
-                        onFocus={() => this.safeSetState({recsFocused: true})}
-                        onBlur={() => this.safeSetState({recsFocused: false})}
-                        helperText={this.state.recsFocused ? `Must be between 1 and ${Global.user.maxRecommendations}` : 'Number of machines considered'}
-                        minValue={1}
-                        maxValue={Global.user.maxRecommendations}
-                        disabledMessage={Global.user.userExpertise < 2 ? emUpSub : ''}
-                    />
                     <TextBox<number>
                         getValue={this.getMaxJobsValue}
                         saveValue={this.saveMaxJobsValue}
@@ -195,7 +194,7 @@ export class AccountLimitsSubMenu extends React.Component<IProps, IAccountLimits
                             {unit: 'minutes', value: 60},
                             {unit: 'hours', value: 3600},
                         ]}
-                        label='Holdover'
+                        label='Auto-release'
                         labelWidth={LABEL_WIDTH}
                         onFocus={() => this.safeSetState({holdoverFocused: true})}
                         onBlur={() => this.safeSetState({holdoverFocused: false})}
