@@ -33,6 +33,7 @@ interface IProps<T> {
     minValue?: T
     maxValue?: T
     helperText?: string
+    helperLink?: {link: string, text: string}
     onFocus?: (event: React.FocusEvent<HTMLInputElement>) => void
     onBlur?: (event: React.FocusEvent<HTMLInputElement>) => void
     multiline?: boolean
@@ -332,7 +333,7 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                         {this.renderLabelOverButton(!showLabel)}
                     </div>
                 )}
-                {/* <ExtraInfo reminder={this.state.invalidTextMessage}> */}
+                <ExtraInfo reminder={this.state.invalidTextMessage}>
                     <FormControl
                         error={this.state.invalidTextMessage != ''}
                         variant='outlined'
@@ -362,7 +363,7 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                             })()}
                             endAdornment={
                                 (this.props.disabled || !(this.props.disabledMessage == undefined || this.props.disabledMessage == '')) ? (
-                                    <ExtraInfo reminder={this.props.disabledMessage}>
+                                    // <ExtraInfo reminder={this.props.disabledMessage}>
                                         <InputAdornment position="end" style={{height: '20px', margin: '0px 3px 0px 0px'}}>
                                             <IconButton
                                                 disabled
@@ -371,10 +372,10 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                                                 <LockIcon style={{width: '14px', height: '14px'}} />
                                             </IconButton>
                                         </InputAdornment>
-                                    </ExtraInfo>
+                                    // </ExtraInfo>
                                 ) : this.props.password && (
-                                    <ExtraInfo reminder={this.state.hidePassword ? 'Show Password' : 'Hide Password'}>
-<                                        InputAdornment position="end" style={{height: '20px', margin: '0px 3px 0px 0px'}}>
+                                    // <ExtraInfo reminder={this.state.hidePassword ? 'Show Password' : 'Hide Password'}>
+                                        <InputAdornment position="end" style={{height: '20px', margin: '0px 3px 0px 0px'}}>
                                             <IconButton
                                                 onClick={() => this.safeSetState({hidePassword: !this.state.hidePassword})}
                                                 style={{padding: '3px 3px 3px 0px'}}
@@ -386,17 +387,22 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                                                 )}
                                             </IconButton>
                                         </InputAdornment>
-                                    </ExtraInfo>
+                                    // </ExtraInfo>
                                 )
                             }
                         />
                         {this.props.helperText && 
-                            <FormHelperText style={{fontSize: '10px', lineHeight: '10px', margin: '4px 6px', whiteSpace: 'nowrap'}}>
+                            <FormHelperText style={{fontSize: '10px', lineHeight: '10px', margin: '4px 6px', whiteSpace: 'nowrap', display: 'inline-flex'}}>
                                 {this.props.helperText}
+                                {this.props.helperLink && (
+                                    <a href={this.props.helperLink.link} target="_blank" style={{flexGrow: 1, textAlign: 'end', fontStyle: 'italic'}}>
+                                        {this.props.helperLink.text}
+                                    </a>
+                                )}
                             </FormHelperText>
                         }
                     </FormControl>
-                {/* </ExtraInfo> */}
+                </ExtraInfo>
             </div>
         )
     }
