@@ -13,6 +13,7 @@ import { Global } from '../../Global';
 interface IProps {
     cell: any
     metadata: any
+    renderInColor: boolean
 }
 
 interface IState {}
@@ -23,7 +24,7 @@ export default class CodeCell extends React.Component<IProps, IState> {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <div className='p-Widget lm-Widget jp-Cell jp-CodeCell jp-Notebook-cell' onContextMenu={(e) => e.preventDefault()}>
-                <InputArea cell={this.props.cell} metadata={this.props.metadata} />
+                <InputArea cell={this.props.cell} metadata={this.props.metadata} renderInColor={this.props.renderInColor} />
                 <OutputArea cell={this.props.cell} metadata={this.props.metadata} />
             </div>
         )
