@@ -13,6 +13,7 @@ import { Global } from '../../Global';
 interface IProps {
     cell: any
     metadata: any
+    renderInColor: boolean
 }
 
 interface IState {}
@@ -36,7 +37,7 @@ export default class InputArea extends React.Component<IProps, IState> {
                     )}
                     </div>
                     {this.props.cell.cell_type === 'code' ? (
-                        <Editor cell={this.props.cell} metadata={this.props.metadata} />
+                        <Editor cell={this.props.cell} metadata={this.props.metadata} renderInColor={this.props.renderInColor} />
                     ) : this.props.cell.cell_type === 'markdown' ? (
                         <Markdown cell={this.props.cell} metadata={this.props.metadata} />
                     ) : (
