@@ -12,6 +12,7 @@ import { Global } from '../../Global';
 interface IProps {
     cell: any
     metadata: any
+    renderInColor: boolean
 }
 
 interface IState {}
@@ -22,7 +23,7 @@ export default class MarkdownCell extends React.Component<IProps, IState> {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <div className='p-Widget lm-Widget jp-Cell jp-MarkdownCell jp-Notebook-cell'>
-                <InputArea cell={this.props.cell} metadata={this.props.metadata} />
+                <InputArea cell={this.props.cell} metadata={this.props.metadata} renderInColor={this.props.renderInColor} />
             </div>
         )
     }
