@@ -22,14 +22,17 @@ export default class Notebook extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         const notebook = this.props.notebook
+        // const words = notebook.cells.map(cell => (cell.source as string).split(/\b/).length).reduce((a, b) => a + b, 0)
+        const words = notebook.cells.map(cell => cell.source.length).reduce((a, b) => a + b, 0) / 5
+        const renderInColor = words < 2500
         let i = 0;
         return (
             <div className='p-Widget lm-Widget jp-Notebook jp-NotebookPanel-notebook jp-mod-scrollPastEnd jp-mod-commandMode'>
                 {notebook.cells.map(cell => 
                     cell.cell_type === 'code' ? (
-                        <CodeCell key={i++} cell={cell} metadata={notebook.metadata} />
+                        <CodeCell key={i++} cell={cell} metadata={notebook.metadata} renderInColor={renderInColor} />
                     ) : cell.cell_type === 'markdown' ? (
-                        <MarkdownCell key={i++} cell={cell} metadata={notebook.metadata} />
+                        <MarkdownCell key={i++} cell={cell} metadata={notebook.metadata} renderInColor={renderInColor} />
                     ) : (
                         <></>
                     )
