@@ -5,8 +5,6 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { ISignal, Signal } from '@lumino/signaling';
-
 import { ServerConnection } from '@jupyterlab/services';
 import { Global } from '../Global';
 import { Update } from './Update';
@@ -14,18 +12,12 @@ import { OutputFile } from './OutputFile';
 import { Machine } from './machine/Machine';
 
 export enum Status {
-	Initializing,
-	Running,
-	Completed,
+	INITIALIZING,
+	RUNNING,
+	COMPLETED,
 }
 
 export class Module {
-	private _changed = new Signal<this, Module>(this);
-
-	get changed(): ISignal<this, Module> {
-		return this._changed;
-	}
-
 	private _sessionReady: boolean = false;
 
 	get sessionReady(): boolean {
@@ -44,9 +36,9 @@ export class Module {
     
     private _output: Update[];
     private _files: OutputFile[];
-    private _updates: string[];
+    private _updates: Update[];
 
-	constructor(uuid: string, workloadUUID: string, addOutput: (line: string, modifier: string) => void, machine: Machine = null, sessionToken: string = null, output: Update[] = [], updates: string[] = [], files: OutputFile[] = []) {
+	constructor(uuid: string, workloadUUID: string, addOutput: (line: string, modifier: string) => void, machine: Machine = null, sessionToken: string = null, output: Update[] = [], updates: Update[] = [], files: OutputFile[] = []) {
 		this._uuid = uuid;
 		this._workloadUUID = workloadUUID;
 		this.addOutput = addOutput;
@@ -61,8 +53,8 @@ export class Module {
 		}
 		this._sessionReady = output.map(x => x.line.includes('Jupyter Server ') && x.line.includes(' is running at:')).includes(true);
 
-		this._files = files;
 		this._updates = updates;
+		this._files = files;
 	}
 
 	get uuid(): string {
@@ -85,7 +77,7 @@ export class Module {
         return this._machine;
     }
 
-	get updates(): String[] {
+	get updates(): Update[] {
         return this._updates;
     }
 
@@ -98,14 +90,20 @@ export class Module {
 	}
 
 	get modStatus(): Status {
-		return (this._updates.includes("closed") || this._updates.includes("stop")) ? Status.Completed : Status.Running;
+		for (var update of this._updates) {
+			if (update.modifier == "stop") return Status.COMPLETED;
+		}
+		return Status.RUNNING;
 	}
 
 	get error(): boolean {
-		return this._updates.includes("error");
+		for (var update of this._updates) {
+			if (update.line == "error") return true;
+		}
+		return false;
     }
 
-	public handleUpdate(body: any) {
+	public handleUpdate(body: any): boolean {
 		let updated = false
 		if (body.output != null) {
 			if (body.output.length > 0) updated = true;
@@ -133,12 +131,12 @@ export class Module {
 		}
 		if (body.updates != null) {
 			if (body.updates.length > 0) updated = true;
-			for (var update of body.updates) {
-				this._updates.push(update);
-				if (update == "stop") {
-					this._updates.push("stop");
-				} else if (update == "launched") {
-				} else if (update == "closed") {
+			for (let i = 0; i < body.updates.length; i++) {
+				this._updates.push(new Update(body.updates[i], body.updatesmod[i]));
+				if (body.updatesmod[i] == "stop") {
+					this.stopSessionHandler();
+				} else if (body.updates[i] == "launched") {
+				} else if (body.updates[i] == "closed") {
 					this.stopSessionHandler();
 				}
 			}
@@ -147,10 +145,7 @@ export class Module {
 			updated = true;
 			this._machine = Object.setPrototypeOf(body.machine, Machine.prototype);
 		}
-		if (updated) {
-			if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
-			this._changed.emit(this);
-		}
+		return updated;
 	}
 
     public pushModuleInput = (line: string) => {
