@@ -5,12 +5,13 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { Phase } from './App';
+import { Phase } from './application/App';
 
 import { ServerConnection } from '@jupyterlab/services';
 import { Global } from '../Global';
 import { Update } from './Update';
 import FormatUtils from '../utils/FormatUtils';
+import NotebookUtils from '../utils/NotebookUtils';
 
 export class ProgressMessage {
 	private _appUUID = "";
@@ -29,21 +30,34 @@ export class ProgressMessage {
 	public get message(): string {
 		for (let i = this._updates.length -1; i >= 0; i--) {
 			const update = this._updates[i];
-			if (update.line != 'error' && update.line != 'stop' && update.line != '') {
+			if (update.line != 'error' && update.line != 'stop' && update.line != '' && update.modifier != 'detail') {
 				return update.line;
 			} 
 		}
 		return "";
     }
 
-    public get messages(): string[] {
-        const messages: string[] = []
+    public get messages(): string {
+        var messages: string = "";
+		var lastNonDetail = "";
         for (let update of this._updates) {
 			if (update.line != 'error' && update.line != 'stop' && update.line != '') {
-            	messages.push(update.line);
+				if (update.modifier == 'detail') {
+					if (update.line.startsWith('\b')) {
+						messages += ('\b\b\b\b' + update.line)
+					} else {
+            			messages += ('    ' + update.line)
+					}
+				} else {
+					// Suppress duplicate update messages
+					if (update.line != lastNonDetail) {
+						messages += update.line + '\n'
+						lastNonDetail = update.line
+					}
+				}
 			}
         }
-		return messages;
+		return NotebookUtils.fixOverwrittenChars(messages);
     }
 
 	// There are cases where we do not want to send an update to the controller
@@ -69,10 +83,13 @@ export class ProgressMessage {
             var end = new Date().getTime();
             if (this.completed) {
                 for (let update of this._updates) {
-                    var date = Date.parse(update.modifier)
-                    if (!isNaN(date)) {
-                        end = date;
-                    }
+					// If the update does not have a valid date, ignore it
+					try {
+						var date = Date.parse(update.modifier)
+						if (!isNaN(date)) {
+							end = date;
+						}
+					} catch (err) {}
                 }
             }
             return FormatUtils.msToTime(end - start);
@@ -85,10 +102,13 @@ export class ProgressMessage {
 		var end = new Date().getTime();
 		if (this.completed) {
 			for (let update of this._updates) {
-				var date = Date.parse(update.modifier)
-				if (!isNaN(date)) {
-					end = date;
-				}
+				// If the update does not have a valid date, ignore it
+				try {
+					var date = Date.parse(update.modifier)
+					if (!isNaN(date)) {
+						end = date;
+					}
+				} catch (err) {}
 			}
 			return new Date(end);
 		}
