@@ -5,8 +5,8 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { App } from './App';
-import { AppTracker } from './AppTracker';
+import { App } from './application/App';
+import { AppTracker } from './application/AppTracker';
 
 import { ServerConnection } from '@jupyterlab/services';
 
@@ -27,6 +27,7 @@ export class User {
         const newUser = new User(
             responseData.newAgreement,
             responseData.name,
+            responseData.phoneNumber,
             responseData.intent,
             responseData.userBudget,
             responseData.maxBudget,
@@ -56,6 +57,7 @@ export class User {
 			responseData.noRequirementsPreventEnabled,
 			responseData.noFileUploadsPreventEnabled,
 			responseData.startSessionPreventEnabled,
+			responseData.notificationsEnabled,
             new AppTracker(),
             new Machines(machines, responseData.maxRate)
         );
@@ -78,6 +80,7 @@ export class User {
     private _unsignedAgreement: boolean;
 
 	private _name: string;
+	private _phoneNumber: string;
 	private _intent: number;
 	private _userBudget: number;
 	private _maxBudget: number;
@@ -107,13 +110,14 @@ export class User {
 	private _noRequirementsPreventEnabled: boolean;
 	private _noFileUploadsPreventEnabled: boolean;
 	private _startSessionPreventEnabled: boolean;
+	private _notificationsEnabled: boolean;
 
 	private _appTracker: AppTracker;
 	private _machines: Machines;
 
 	private _deploySubMenu: Page = Page.RESOURCES;
 
-    constructor(unsignedAgreement: boolean, name: string, intent: number, 
+    constructor(unsignedAgreement: boolean, name: string, phoneNumber: string, intent: number, 
         userBudget: number, maxBudget: number, budgetCap: number, 
         userRate: number, maxRate: number, rateCap: number, 
         userAggregateRate: number, maxAggregateRate: number, aggregateRateCap: number, 
@@ -123,10 +127,11 @@ export class User {
         maxMachines: number, machinesCap: number, 
 		userExpertise: number, proactiveUploadsEnabled: boolean, compressFilesEnabled: boolean, lastPage: number, 
 		stopJobPreventEnabled: boolean, deleteJobPreventEnabled: boolean, noRequirementsPreventEnabled: boolean, noFileUploadsPreventEnabled: boolean, 
-		startSessionPreventEnabled: boolean,
+		startSessionPreventEnabled: boolean, notificationsEnabled: boolean,
 		appTracker: AppTracker, machines: Machines) {
         this._unsignedAgreement = unsignedAgreement === undefined ? true : unsignedAgreement;
         this._name = name;
+        this._phoneNumber = phoneNumber;
 		this._intent = intent;
         this._userBudget = userBudget;
         this._maxBudget = maxBudget;
@@ -157,6 +162,7 @@ export class User {
 		this._noRequirementsPreventEnabled = noRequirementsPreventEnabled;
 		this._noFileUploadsPreventEnabled = noFileUploadsPreventEnabled;
 		this._startSessionPreventEnabled = startSessionPreventEnabled;
+		this._notificationsEnabled = notificationsEnabled;
 
 		this._appTracker = appTracker;
         this._machines = machines;
@@ -184,6 +190,18 @@ export class User {
 		this._name = name;
 	}
 
+	get phoneNumber(): string {
+		return this._phoneNumber;
+	}
+
+	set phoneNumber(phoneNumber: string) {
+		if (phoneNumber === this._phoneNumber) {
+			return;
+		}
+		this.setUserInformation("phoneNumber", phoneNumber);
+		this._phoneNumber = phoneNumber;
+	}
+
 	get deploySubMenu(): Page {
 		return this._deploySubMenu;
 	}
@@ -487,6 +505,18 @@ export class User {
 		this.setUserInformation("startSessionPreventEnabled", startSessionPreventEnabled.toString());
 	}
 
+	get notificationsEnabled(): boolean {
+		return this._notificationsEnabled;
+	}
+
+	set notificationsEnabled(notificationsEnabled: boolean) {
+		if (notificationsEnabled === this._notificationsEnabled) {
+			return;
+		}
+		this._notificationsEnabled = notificationsEnabled;
+		this.setUserInformation("notificationsEnabled", notificationsEnabled.toString());
+	}
+
 	get appTracker(): AppTracker {
 		return this._appTracker;
 	}
