@@ -111,8 +111,8 @@ export class MachineComponent extends React.Component<IProps, IState> {
     
     private showLoading = (machineState: string): boolean => {
         switch (machineState) {
-        case 'Acquiring...':
-        case 'Releasing...':
+        case 'Acquiring':
+        case 'Releasing':
             return true
         default:
             return false
@@ -123,14 +123,6 @@ export class MachineComponent extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         var machine: Machine = this.props.machine
         var tags: JSX.Element[] = []
-        var specialTag: JSX.Element[] = []
-        if (machine.rate != undefined) {
-            specialTag.push(
-                <ExtraInfo key={'machineRate'} reminder='Cost'>
-                    <Tag key={'machineRate'} label={(machine.promo ? 'Promo: ' : '') + FormatUtils.styleRateUnitValue()(machine.rate)} />
-                </ExtraInfo>
-            );
-        }
         var machineState: string = Machine.getStateMessage(this.props.machine.state);
         if (machineState != '') {
             tags.push(
@@ -139,14 +131,16 @@ export class MachineComponent extends React.Component<IProps, IState> {
                 </ExtraInfo>
             );
         }
+        if (machine.rate != undefined) {
+            tags.push(
+                <ExtraInfo key={'machineRate'} reminder='Cost'>
+                    <Tag key={'machineRate'} label={(machine.promo ? 'Promo: ' : '') + FormatUtils.styleRateUnitValue()(machine.rate)} />
+                </ExtraInfo>
+            );
+        }
         const user: User = Global.user;        
 		return (
             <InfoSkirt
-                leftButton={
-                    <ExtraInfo reminder='See details'>
-                        {this.props.machine.getPopupComponent()}
-                    </ExtraInfo>
-                }
                 rightButton={
                     <>
                         <WarningPopup
@@ -157,12 +151,11 @@ export class MachineComponent extends React.Component<IProps, IState> {
                                     if (app.uuid == machine.app) {
                                         const appWord = app.interactive ? "session" : "job";
                                         const appAction = app.interactive ? "closed" : "terminated";
-                                        const appName = app.name.split('/').pop();
                                         // if (app is running) {
                                         if ((app.requisitioning.completed && !app.requisitioning.error) && !app.running.completed) {
-                                            return "Your " + appWord + " '" + appName + "' is active on this machine. It will be " + appAction + " if the machine is released."
+                                            return "Your " + appWord + " '" +  app.name + "' is active on this machine. It will be " + appAction + " if the machine is released."
                                         } else {
-                                            return "Your " + appWord + " '" + appName + "' is waiting for this machine. It will be deleted if the machine is released."
+                                            return "Your " + appWord + " '" +  app.name + "' is waiting for this machine. It will be deleted if the machine is released."
                                         }
                                     }
                                 }
@@ -228,7 +221,6 @@ export class MachineComponent extends React.Component<IProps, IState> {
                     </>
                 }
                 tags={tags}
-                specialTag={specialTag}
             >
                 {this.props.machine.getIdentityComponent()}
             </InfoSkirt>
