@@ -11,7 +11,7 @@ import * as React from 'react';
 import { Global } from '../Global';
 import { withStyles } from '@material-ui/core';
 
-const REMOVE_EXTRA_INFO_CAUSE_ISSUE = true
+const REMOVE_EXTRA_INFO_CAUSE_ISSUE = false
 
 // Include the bootstrap styles once
 if (!REMOVE_EXTRA_INFO_CAUSE_ISSUE) document.body.innerHTML += `<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.0/css/bootstrap.min.css" integrity="sha384-9aIt2nRpC12Uk9gS9baDl411NQApFmC26EwAOH8WgZl5MYYxFfc+NcPb1dKGj7Sk" crossorigin="anonymous" />`
@@ -68,7 +68,7 @@ export default /*React.memo(*/function ExtraInfo(props: ExtraInfoProps) {
         if (onMouseOut) return onMouseOut(args)
     }
 
-    const StyledPopover = withStyles({
+    const StyledPopover = React.useMemo(() => withStyles({
         '@global': {
             '#styled-popover *': {
                 color: `var(--jp-ui-font-color1)`,
@@ -79,6 +79,7 @@ export default /*React.memo(*/function ExtraInfo(props: ExtraInfoProps) {
             '#styled-popover': {
                 zIndex: `1300`,
                 borderColor: `var(--jp-ui-font-color1)`,
+                maxWidth: `none`,
             },
             '#styled-popover .popover-header': {
                 backgroundColor: `var(--jp-layout-color2)`,
@@ -91,6 +92,10 @@ export default /*React.memo(*/function ExtraInfo(props: ExtraInfoProps) {
             '#styled-popover .popover-body': {
                 backgroundColor: `var(--jp-layout-color1)`,
             },
+            '#styled-popover .arrow': {
+                left: !Global.inQuestionMode ? '-4px !important' : undefined, // Not sure what this is about, it didn't use to require this, then all of a sudden it did
+                top: Global.inQuestionMode ? '-5px !important' : undefined,
+            },
             '#styled-popover .arrow::before': {
                 borderRightColor: Global.inQuestionMode ? `var(--jp-ui-font-color1)` : undefined,
                 borderTopColor: !Global.inQuestionMode ? `var(--jp-ui-font-color1)` : undefined,
@@ -102,7 +107,7 @@ export default /*React.memo(*/function ExtraInfo(props: ExtraInfoProps) {
                 bottom: Global.inQuestionMode ? undefined : (Global.themeManager == undefined || Global.themeManager.isLight(Global.themeManager.theme)) ? '1px' : '2px',
             },
         }
-    })(Popover)
+    })(Popover), [Global.inQuestionMode, Global.themeManager])
 
     const hasReminder = reminder !== undefined && reminder !== ''
     const hasOverview = overview !== undefined && overview !== ''
@@ -111,7 +116,6 @@ export default /*React.memo(*/function ExtraInfo(props: ExtraInfoProps) {
     return (REMOVE_EXTRA_INFO_CAUSE_ISSUE || (!hasReminder && !hasOverview)) ? children : ( // Render
         <OverlayTrigger
             delay={{show: Global.inQuestionMode ? 10 : 500, hide: 10}}
-            trigger={['hover', 'click', 'focus']}
             placement={Global.inQuestionMode ? 'right' : 'top'}
             overlay={Global.inQuestionMode ? (
                 <StyledPopover /*key={'questionMode' + reminder + overview}*/ id='styled-popover'>
@@ -159,4 +163,4 @@ export default /*React.memo(*/function ExtraInfo(props: ExtraInfoProps) {
     if (JSON.stringify(props.children) !== JSON.stringify(nextProps.children)) return false;
     if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
     return true
-})*/
\ No newline at end of file
+})*/
